==> scummvm_1.6.0+dfsg.orig.tar.xz: scummvm-1.6.0/engines/wintermute/ad/ad_path_point.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

/*
 * This file is based on WME Lite.
 * http://dead-code.org/redir.php?target=wmelite
 * Copyright (c) 2011 Jan Nedoma
 */

#ifndef WINTERMUTE_ADPATHPOINT_H
#define WINTERMUTE_ADPATHPOINT_H

#include "engines/wintermute/persistent.h"
#include "engines/wintermute/base/base_point.h"

namespace Wintermute {

class AdPathPoint : public BasePoint {
public:
	DECLARE_PERSISTENT(AdPathPoint, BasePoint)
	AdPathPoint(int initX, int initY, int initDistance);
	AdPathPoint();
	virtual ~AdPathPoint();
	AdPathPoint *_origin;
	bool _marked;
	int32 _distance;
};

} // end of namespace Wintermute

#endif

==> scummvm_2.5.1+dfsg.orig.tar.xz: scummvm-2.5.1/engines/wintermute/ad/ad_path_point.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

/*
 * This file is based on WME Lite.
 * http://dead-code.org/redir.php?target=wmelite
 * Copyright (c) 2011 Jan Nedoma
 */

#ifndef WINTERMUTE_ADPATHPOINT_H
#define WINTERMUTE_ADPATHPOINT_H

#include "engines/wintermute/persistent.h"
#include "engines/wintermute/base/base_point.h"

namespace Wintermute {

class AdPathPoint : public BasePoint {
public:
	DECLARE_PERSISTENT(AdPathPoint, BasePoint)
	AdPathPoint(int initX, int initY, int initDistance);
	AdPathPoint();
	~AdPathPoint() override;
	AdPathPoint *_origin;
	bool _marked;
	int32 _distance;
};

} // End of namespace Wintermute

#endif
